=== modified file 'loggerhead/apps/branch.py'
--- loggerhead/apps/branch.py	2011-06-27 14:02:26 +0000
+++ loggerhead/apps/branch.py	2011-06-27 14:17:38 +0000
@@ -37,7 +37,7 @@
 from loggerhead.controllers.filediff_ui import FileDiffUI
 from loggerhead.controllers.inventory_ui import InventoryUI
 from loggerhead.controllers.revision_ui import RevisionUI
-from loggerhead.controllers.revlog_ui import RevLogUI, RevLogJSONUI
+from loggerhead.controllers.revlog_ui import RevLogUI
 from loggerhead.controllers.search_ui import SearchUI
 from loggerhead.history import History
 from loggerhead import util
@@ -128,10 +128,6 @@
         'view': ViewUI,
         }
 
-    json_controllers_dict = {
-        '+revlog': RevLogJSONUI,
-        }
-
     def last_updated(self):
         h = self.get_history()
         change = h.get_changes([h.last_revid])[0]
@@ -169,9 +165,11 @@
         if path == 'static':
             return static_app(environ, start_response)
         elif path == '+json':
-            path2 = request.path_info_pop(environ)
-            cls = self.json_controllers_dict.get(path2)
+            json = True
+            path = request.path_info_pop(environ)
+            cls = self.controllers_dict.get(path)
         else:
+            json = False
             cls = self.controllers_dict.get(path)
         if cls is None:
             raise httpexceptions.HTTPNotFound()
@@ -179,7 +177,10 @@
         try:
             try:
                 c = cls(self, self.get_history)
-                return c(environ, start_response)
+                if json:
+                    return c.jsoncall(environ, start_response)
+                else:
+                    return c(environ, start_response)
             except:
                 environ['exc_info'] = sys.exc_info()
                 environ['branch'] = self

=== modified file 'loggerhead/controllers/__init__.py'
--- loggerhead/controllers/__init__.py	2011-06-27 14:02:26 +0000
+++ loggerhead/controllers/__init__.py	2011-06-27 14:17:38 +0000
@@ -18,6 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import bzrlib.errors
+import simplejson
 import time
 
 from paste.httpexceptions import HTTPNotFound
@@ -117,6 +118,30 @@
                 self.__class__.__name__, time.time() - z, w.bytes))
         return []
 
+    def jsoncall(self, environ, start_response):
+        z = time.time()
+        json_values, headers = self.get_json_values(environ)
+
+        # XXX de-dupe this code.
+        self.log.info('Getting information for %s: %.3f secs' % (
+            self.__class__.__name__, time.time() - z))
+        #headers['Content-Type'] = 'application/json'
+        headers['Content-Type'] = 'text/plain'
+        writer = start_response("200 OK", headers.items())
+        if environ.get('REQUEST_METHOD') == 'HEAD':
+            # No content for a HEAD request
+            return []
+        z = time.time()
+        w = BufferingWriter(writer, 8192)
+
+        w.write(simplejson.dumps(json_values,
+            default=util.convert_to_json_ready))
+        w.flush()
+        self.log.info(
+            'Rendering %s: %.3f secs, %s bytes' % (
+                self.__class__.__name__, time.time() - z, w.bytes))
+        return []
+
     def get_revid(self):
         h = self._history
         if h is None:

=== modified file 'loggerhead/controllers/revlog_ui.py'
--- loggerhead/controllers/revlog_ui.py	2011-06-27 14:02:26 +0000
+++ loggerhead/controllers/revlog_ui.py	2011-06-27 14:17:38 +0000
@@ -1,5 +1,4 @@
 import datetime
-import simplejson
 import time
 import urllib
 
@@ -29,45 +28,7 @@
             'url': self._branch.context_url,
         }
 
-
-class RevLogJSONUI(RevLogUI):
-
     def get_json_values(self, environ):
         core_values, headers = self.get_core_values(environ)
         del core_values['branch'], core_values['util'], core_values['url']
-#        print core_values
-#        core_values['entry'] = core_values['entry']._properties
-#        core_values['file_changes'] = core_values['file_changes']._properties
-
         return core_values, headers
-
-    def __call__(self, environ, start_response):
-        z = time.time()
-        json_values, headers = self.get_json_values(environ)
-
-        # XXX de-dupe this code.
-        self.log.info('Getting information for %s: %.3f secs' % (
-            self.__class__.__name__, time.time() - z))
-        #headers['Content-Type'] = 'application/json'
-        headers['Content-Type'] = 'text/plain'
-        writer = start_response("200 OK", headers.items())
-        if environ.get('REQUEST_METHOD') == 'HEAD':
-            # No content for a HEAD request
-            return []
-        z = time.time()
-        w = BufferingWriter(writer, 8192)
-        def encode_stuff(obj):
-            if isinstance(obj, util.Container):
-                d = obj.__dict__.copy()
-                del d['_properties']
-                return d
-            elif isinstance(obj, datetime.datetime):
-                return tuple(obj.utctimetuple())
-            raise TypeError(repr(obj) + " is not JSON serializable")
-
-        w.write(simplejson.dumps(json_values, default=encode_stuff))
-        w.flush()
-        self.log.info(
-            'Rendering %s: %.3f secs, %s bytes' % (
-                self.__class__.__name__, time.time() - z, w.bytes))
-        return []

=== modified file 'loggerhead/util.py'
--- loggerhead/util.py	2011-03-23 05:21:34 +0000
+++ loggerhead/util.py	2011-06-27 14:17:38 +0000
@@ -663,3 +663,13 @@
             else:
                 raise
     return new_application
+
+
+def convert_to_json_ready(obj):
+    if isinstance(obj, Container):
+        d = obj.__dict__.copy()
+        del d['_properties']
+        return d
+    elif isinstance(obj, datetime.datetime):
+        return tuple(obj.utctimetuple())
+    raise TypeError(repr(obj) + " is not JSON serializable")

